/***********************************************
 * THEME: ANIMATED BLOCK
 ***********************************************/
(function ($) {

	'use strict';

	PTFJS.animatedBlock = {
		init: function () {

			var animatedBlock = $('.ptf-animate-element'),
				prefix = 'animate__';

			if ($('.ptf-fullpage-slider').length) {

				PTFJS.window.on('ptf.change-slide', function () {
					animatedBlock.each(function () {
						var $this = $(this);
						var animationName = $this.data('animation-name');
						$this.removeClass(prefix + 'animated').removeClass(prefix + animationName);
						if ($this.parents('.ptf-section').hasClass('active')) {
							$this.addClass(prefix + 'animated').addClass(prefix + animationName);
						}
					});
				});

			} else {
				animatedBlock.each(function () {
					var $this = $(this);
					$this.one('inview', function () {
						var animationName = $this.data('animation-name');
						$this.addClass(prefix + 'animated').addClass(prefix + animationName);
					});
				});
			}
		}
	};

	PTFJS.animatedBlock.init();

})(jQuery);
/***********************************************
 * THEME: CUSTOM CURSOR
 ***********************************************/
(function ($) {

	'use strict';

	PTFJS.customCursor = {
		init: function () {

			if (!$('.ptf-custom-cursor').length) {
				PTFJS.body.append('<div class="ptf-custom-cursor"></div>');
			}

			var customCursor = $('.ptf-custom-cursor'),
				isActive = false;

			$('[data-cursor]').each(function () {
				var $this = $(this),
					value = $this.data('cursor');

				$this.on('mousemove', show),
				$this.on('mouseleave', hide);

				function show() {
					if (!isActive) {
						customCursor.addClass('active');
						customCursor.css('background-image', `url(${value})`);
						isActive = true;
					}
				}

				function hide() {
					if (isActive) {
						customCursor.removeClass('active');
						isActive = false;
					}
				}

			});

			$('[data-cursor]').on('mousemove pointermove', trackPosition);

			function trackPosition(e) {
				customCursor.css({
					top: e.clientY + 'px',
					left: e.clientX + 'px'
				});
			}

		}
	};

	PTFJS.customCursor.init();

	PTFJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/ptf-timeline.default',
			PTFJS.customCursor.init
		);
	});

})(jQuery);
/***********************************************
 * THEME: FULLPAGE SLIDER
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof $.fn.pagepiling == 'undefined') {
		return;
	}

	PTFJS.fullpageSlider = {

		init: function () {

			var fullpageSlider = $('.ptf-fullpage-slider'),
				progressBar = fullpageSlider.find('.ptf-nav-widget'),
				loopTop = fullpageSlider.data('loop-top') ? true : false,
				loopBottom = fullpageSlider.data('loop-bottom') ? true : false,
				speed = fullpageSlider.data('speed') || 800,
				anchors = [];

			if (!fullpageSlider.length) {
				return;
			}

			$('.ptf-offcanvas-menu ul.sf-menu > li:first-of-type').addClass('active');

			PTFJS.body.css('overflow', 'hidden');
			PTFJS.html.css('overflow', 'hidden');

			fullpageSlider.find('[data-anchor]').each(function () {
				anchors.push($(this).data('anchor'));
			});

			function ptfhemes_navigation() {
				var total = fullpageSlider.find('.ptf-section').length,
					current = fullpageSlider.find('.ptf-section.active').index(),
					scale = (current + 1) / total;

				progressBar.find('.ptf-nav-widget__line>span').css({
					'transform': 'scaleX(' + scale + ')'
				});

				progressBar.find('.ptf-nav-widget__number').html(current + 1 + '/' + total);

			}

			fullpageSlider.pagepiling({
				menu: '.ptf-offcanvas-menu ul.sf-menu, .ptf-navbar-menu ul.sf-menu, .ptf-footer-menu ul.sf-menu',
				scrollingSpeed: speed,
				loopTop: loopTop,
				loopBottom: loopBottom,
				anchors: anchors,
				sectionSelector: '.ptf-section',
				navigation: false,
				afterRender: function () {
					ptfhemes_navigation();
					PTFJS.window.trigger('ptf.change-slide');
				},
				onLeave: function () {
					ptfhemes_navigation();
					PTFJS.window.trigger('ptf.change-slide');
				}
			});

		}
	};

	PTFJS.fullpageSlider.init();

})(jQuery);
/***********************************************
 * THEME: NAVBAR
 ***********************************************/
(function ($) {
	'use strict';

	var navbarMain = $('.ptf-navbar--main'),
		navbarHeight = navbarMain.outerHeight(),
		navbarMainOffset = 0;

	// fake navbar
	var navbarFake = $('<div class="ptf-fake-navbar">').hide();

	// fixed navbar
	function _fixed_navbar() {
		navbarMain.addClass('ptf-navbar--fixed');
		navbarFake.show();
		// add solid color
		if (navbarMain.hasClass('ptf-navbar--transparent') && navbarMain.hasClass('ptf-navbar--sticky')) {
			navbarMain.addClass('ptf-navbar--solid');
		}
	}

	function _unfixed_navbar() {
		navbarMain.removeClass('ptf-navbar--fixed');
		navbarFake.hide();
		// remove solid color
		if (navbarMain.hasClass('ptf-navbar--transparent') && navbarMain.hasClass('ptf-navbar--sticky')) {
			navbarMain.removeClass('ptf-navbar--solid');
		}
	}

	function _on_scroll_navbar() {
		if (PTFJS.window.scrollTop() > navbarMainOffset) {
			_fixed_navbar();
		} else {
			_unfixed_navbar();
		}
	}

	if (navbarMain.hasClass('ptf-navbar--sticky')) {
		PTFJS.window.on('scroll resize', _on_scroll_navbar);
		_on_scroll_navbar();
		// append fake navbar
		navbarMain.after(navbarFake);
		// fake navbar height after resize
		navbarFake.height(navbarHeight);
		PTFJS.debounceResize(function () {
			navbarFake.height(navbarHeight);
		});
	}

})(jQuery);
/***********************************************
 * THEME: MENU OFFCANVAS
 ***********************************************/
(function ($) {

	'use strict';

	var menuIsOpen = false;

	PTFJS.menuOffcanvas = {
		config: {
			easing: 'power2.out'
		},
		init: function () {
			var menu = $('.ptf-offcanvas-menu'),
				navigation = menu.find('ul.sf-menu'),
				navigationItem = navigation.find('> li'),
				menuToggle = $('.js-offcanvas-menu-toggle');

			if (typeof $.fn.superclick !== 'undefined') {
				navigation.superclick({
					delay: 300,
					cssArrows: false,
					animation: {
						opacity: 'show',
						height: 'show'
					},
					animationOut: {
						opacity: 'hide',
						height: 'hide'
					},
				});
			}

			menuToggle.on('click', function (e) {
				e.preventDefault();
				if (!menuIsOpen) {
					PTFJS.menuOffcanvas.open_menu(menu);
				} else {
					PTFJS.menuOffcanvas.close_menu(menu);
				}
			});

			PTFJS.document.keyup(function (e) {
				if (e.keyCode === 27 && menuIsOpen) {
					e.preventDefault();
					PTFJS.menuOffcanvas.close_menu(menu);
				}
			});

			// Close after click to anchor.
			navigationItem.filter('[data-menuanchor]').on('click', 'a', function () {
				if (menuIsOpen) {
					PTFJS.menuOffcanvas.close_menu(menu);
				}
			});

		},
		open_menu: function (menu) {
			menuIsOpen = true;
			menu.addClass('is-open');
		},
		close_menu: function (menu) {
			menuIsOpen = false;
			menu.removeClass('is-open');
		}
	};

	PTFJS.menuOffcanvas.init();

})(jQuery);
/***********************************************
 * RYENKING: OTHER SCRIPTS
 ***********************************************/
(function ($) {
	'use strict';

	// Back to top
	$('.ptf-back-to-top').on('click', function (e) {
		e.preventDefault();
		setTimeout(function () {
			window.scrollTo({
				top: 0,
				behavior: 'smooth',
			});
		}, 2);
	});

	// Widget menu
	if (typeof $.fn.superclick !== 'undefined') {
		$('.widget_pages > ul, .widget_nav_menu ul.menu').superclick({
			delay: 300,
			cssArrows: false,
			animation: {
				opacity: 'show',
				height: 'show'
			},
			animationOut: {
				opacity: 'hide',
				height: 'hide'
			},
		});
	}

	// Fast click
	if (typeof FastClick === 'function') {
		FastClick.attach(document.body);
	}

	// Fitvids
	if (typeof $.fn.fitVids !== 'undefined') {
		PTFJS.body.fitVids();
	}

	// Masonry blog
	$('.masonry').ptf_masonry_grid();

})(jQuery);
/***********************************************
 * THEME: PRELOADER
 ***********************************************/
(function ($) {

	'use strict';

	function fadeOutPreloader() {
		$('.ptf-preloader').fadeOut(150);
		PTFJS.window.trigger('ptf.preloader_done');
		PTFJS.html.addClass('ptf-is-page-loaded');
	}

	setTimeout(fadeOutPreloader, 600);

})(jQuery);
/***********************************************
 * THEME: STRETCH ELEMENT
 ***********************************************/
(function ($) {

	'use strict';

	PTFJS.stretchElement = {
		init: function () {

			var winW = PTFJS.window.outerWidth();

			$('.has-stretch-block').each(function () {

				var $this = $(this),
					rect = this.getBoundingClientRect(),
					offsetLeft = rect.left,
					offsetRight = winW - rect.right,
					elWidth = rect.width;

				if ($this.hasClass('to-left')) {
					$this.find('>*').css('margin-left', -offsetLeft);
					$this.find('>*').css('width', elWidth + offsetLeft + 'px');
				}

				if ($this.hasClass('to-right')) {
					$this.find('>*').css('margin-right', -offsetRight);
					$this.find('>*').css('width', elWidth + offsetRight + 'px');
				}

				if ($this.hasClass('has-reset-mobile') && PTFJS.window.outerWidth() <= 768) {

					$this.find('>*').css({
						'margin-left': '',
						'margin-right': '',
						'width': '100%'
					});

				}

				PTFJS.window.trigger('ptf.stretched');

			});

		}
	}

	PTFJS.stretchElement.init();

	PTFJS.debounceResize(function () {
		PTFJS.stretchElement.init();
	});

})(jQuery);
/***********************************************
 * WIDGET: BLOG SLIDER
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof Swiper === 'undefined') {
		return;
	}

	PTFJS.blogSlider = {
		init: function ($scope, $) {

			var blogSlider = $scope.find('.ptf-blog-slider'),
				anchor = blogSlider.data('navigation-anchor');

			new Swiper(blogSlider, {
				loop: true,
				slidesPerView: 'auto',
				spaceBetween: 10,
				speed: 1000,
				navigation: {
					nextEl: $(anchor).find('.ptf-swiper-button-next'),
					prevEl: $(anchor).find('.ptf-swiper-button-prev')
				},
				breakpoints: {
					575: {
						spaceBetween: 10
					},
					767: {
						spaceBetween: 20
					},
					991: {
						spaceBetween: 30
					},
					1199: {
						spaceBetween: 40
					}
				},
			});

		}
	}

	PTFJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/ptf-blog-slider.default',
			PTFJS.blogSlider.init
		);
	});

})(jQuery);
/***********************************************
 * WIDGET: IMAGE SLIDER
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof Swiper === 'undefined') {
		return;
	}

	PTFJS.imageSlider = {
		init: function ($scope, $) {

			var imageSlider = $scope.find('.ptf-image-slider'),
				anchor = imageSlider.data('navigation-anchor');

			var swiper = new Swiper(imageSlider, {
				init: false,
				loop: true,
				slidesPerView: 1,
				spaceBetween: 10,
				speed: 1000,
				navigation: {
					nextEl: $(anchor).find('.ptf-swiper-button-next'),
					prevEl: $(anchor).find('.ptf-swiper-button-prev')
				},
				breakpoints: {
					575: {
						spaceBetween: 10,
						slidesPerView: 1
					},
					767: {
						spaceBetween: 20,
						slidesPerView: 'auto'
					},
					991: {
						spaceBetween: 30,
						slidesPerView: 'auto'
					},
					1199: {
						spaceBetween: 40,
						slidesPerView: 'auto'
					}
				},
			});

			swiper.init();

		}
	}

	PTFJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/ptf-image-slider.default',
			PTFJS.imageSlider.init
		);
	});

})(jQuery);
/***********************************************
 * WIDGET: SERVICES LIST
 ***********************************************/
(function ($) {

	'use strict';

	PTFJS.servicesList = {
		init: function ($scope, $) {

			var servicesList = $scope.find('.ptf-services-list'),
				card = servicesList.find('.ptf-services-card'),
				cardContent = card.find('.ptf-services-card__content'),
				tab = servicesList.find('.ptf-services-tab');

			card.eq(0).addClass('active');
			card.eq(0).find('.ptf-services-card__content').slideDown();
			tab.eq(0).addClass('active');

			card.on('mouseenter', function () {
				var currentEl = $(this),
					currentCardContent = currentEl.find('.ptf-services-card__content'),
					index = currentEl.index();

				if (!currentEl.hasClass('active')) {
					cardContent.hide();
					card.removeClass('active');
					tab.removeClass('active');
				}

				currentCardContent.slideDown();
				card.eq(index).addClass('active');
				tab.eq(index).addClass('active');

			});

		}
	}

	PTFJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/ptf-services-list.default',
			PTFJS.servicesList.init
		);
	});

})(jQuery);
/***********************************************
 * WIDGET: TESTIMONIAL SLIDER
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof Swiper === 'undefined') {
		return;
	}

	PTFJS.testimonialSlider = {
		init: function ($scope, $) {

			var testimonialSlider = $scope.find('.ptf-testimonial-slider');

			new Swiper(testimonialSlider, {
				loop: true,
				slidesPerView: 'auto',
				spaceBetween: 10,
				speed: 1000,
				navigation: {
					nextEl: testimonialSlider.find('.ptf-swiper-button-next'),
					prevEl: testimonialSlider.find('.ptf-swiper-button-prev')
				},
				breakpoints: {
					575: {
						spaceBetween: 10
					},
					767: {
						spaceBetween: 20
					},
					991: {
						spaceBetween: 30
					},
					1199: {
						spaceBetween: 40
					}
				},
			});

		}
	}

	PTFJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/ptf-testimonial-slider.default',
			PTFJS.testimonialSlider.init
		);
	});

})(jQuery);
/***********************************************
 * WIDGET: WORKS SLIDER
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof Swiper === 'undefined') {
		return;
	}

	PTFJS.worksSlider = {
		init: function ($scope, $) {

			var worksSlider = $scope.find('.ptf-works-slider'),
				anchor = worksSlider.data('navigation-anchor');

			new Swiper(worksSlider, {
				loop: true,
				slidesPerView: 'auto',
				spaceBetween: 10,
				navigation: {
					nextEl: $(anchor).find('.ptf-swiper-button-next'),
					prevEl: $(anchor).find('.ptf-swiper-button-prev'),
				},
				breakpoints: {
					575: {
						spaceBetween: 10
					},
					767: {
						spaceBetween: 20
					},
					991: {
						spaceBetween: 30
					},
					1199: {
						spaceBetween: 40
					}
				},
			});

		}
	}

	PTFJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/ptf-works-slider.default',
			PTFJS.worksSlider.init
		);
	});

})(jQuery);