<?php

/**
 * @author: paul_tf
 * @version: 1.0.0
 */

define( 'RYENKING_THEME_DIRECTORY', trailingslashit( get_template_directory_uri() ) );
define( 'RYENKING_REQUIRE_DIRECTORY', trailingslashit( get_template_directory() ) );
define( 'RYENKING_DEVELOPMENT', false );

/**
 * After setup theme
 */
if ( ! function_exists( 'ryenking_setup' ) ) {
	function ryenking_setup() {

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Ducky, use a find and replace
		 * to change 'ryen-king' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'ryen-king', get_template_directory() . '/languages' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 1920, 9999 );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );
		add_theme_support( 'dark-editor-style' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add custom editor font sizes.
		add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name' => esc_html__( 'Small', 'ryen-king' ),
					'shortName' => esc_html__( 'S', 'ryen-king' ),
					'size' => 14,
					'slug' => 'small',
				),
				array(
					'name' => esc_html__( 'Normal', 'ryen-king' ),
					'shortName' => esc_html__( 'M', 'ryen-king' ),
					'size' => 16,
					'slug' => 'normal',
				),
				array(
					'name' => esc_html__( 'Large', 'ryen-king' ),
					'shortName' => esc_html__( 'L', 'ryen-king' ),
					'size' => 28,
					'slug' => 'large',
				),
				array(
					'name' => esc_html__( 'Huge', 'ryen-king' ),
					'shortName' => esc_html__( 'XL', 'ryen-king' ),
					'size' => 38,
					'slug' => 'huge',
				),
			)
		);

		// Editor color palette.
		add_theme_support( 'editor-color-palette', array(
			array(
				'name' => esc_html__( 'Primary', 'ryen-king' ),
				'slug' => 'primary',
				'color' => ryenking_get_theme_mod( 'accent_color' )
			)
		) );

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );

		// register nav menus
		register_nav_menus( array(
			'primary-menu' => esc_html__( 'Primary Menu', 'ryen-king' ),
			'onepage-menu' => esc_html__( 'Onepage Menu', 'ryen-king' ),
			'navbar-menu' => esc_html__( 'Navbar Menu', 'ryen-king' ),
		) );

		// 991x826
		add_image_size( 'ryenking-991x826_crop', 991, 826, true );
		add_image_size( 'ryenking-991x826', 991 );

		// 1280x720
		add_image_size( 'ryenking-1280x720_crop', 1280, 720, true );
		add_image_size( 'ryenking-1280x720', 1280 );

		// 1920x1080
		add_image_size( 'ryenking-1920x1080_crop', 1920, 1080, true );
		add_image_size( 'ryenking-1920x1080', 1920 );

	}
}
add_action( 'after_setup_theme', 'ryenking_setup' );

/**
 * Content width
 */
if ( ! function_exists( 'ryenking_content_width' ) ) {
	function ryenking_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'ryenking/content_width', 1920 );
	}
}
add_action( 'after_setup_theme', 'ryenking_content_width', 0 );

/**
 * Import ACF fields
 */
if ( ! RYENKING_DEVELOPMENT ) {
	function ryenking_acf_show_admin_panel() {
		return apply_filters( 'ryenking/acf_show_admin_panel', false );
	}
	add_filter( 'acf/settings/show_admin', 'ryenking_acf_show_admin_panel' );
}

if ( ! RYENKING_DEVELOPMENT ) {
	require_once RYENKING_REQUIRE_DIRECTORY . 'inc/helper/custom-fields/custom-fields.php';
}

if ( ! function_exists( 'ryenking_acf_save_json' ) ) {
	function ryenking_acf_save_json( $path ) {
		$path = RYENKING_REQUIRE_DIRECTORY . 'inc/helper/custom-fields';
		return $path;
	}
}
add_filter( 'acf/settings/save_json', 'ryenking_acf_save_json' );

if ( RYENKING_DEVELOPMENT ) {
	if ( ! function_exists( 'ryenking_acf_load_json' ) ) {
		function ryenking_acf_load_json( $paths ) {
			unset( $paths[0] );
			$paths[] = RYENKING_REQUIRE_DIRECTORY . 'inc/helper/custom-fields';
			return $paths;
		}
	}
	add_filter( 'acf/settings/load_json', 'ryenking_acf_load_json' );
}

/**
 * Include Kirki fields
 */
require_once RYENKING_REQUIRE_DIRECTORY . 'inc/framework/customizer-helper.php';
require_once RYENKING_REQUIRE_DIRECTORY . 'inc/framework/customizer.php';

/**
 * Required files
 */
$ryenking_theme_includes = array(
	'required-plugins',
	'enqueue',
	'includes',
	'ocdi',
	'functions',
	'actions',
	'filters',
	'menus',
	'elementor'
);

foreach ( $ryenking_theme_includes as $file ) {
	require_once RYENKING_REQUIRE_DIRECTORY . 'inc/theme-' . $file . '.php';
}

// Unset the global variable.
unset( $ryenking_theme_includes );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328959&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        